==> 0.0.1.tar.gz: lib/video360kaltura.dart <==
import 'dart:async';
import 'dart:collection';
import 'dart:io';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class Video360PlayerController {

  MethodChannel _channel;

  Video360PlayerController.init(int id) {
    _channel = new MethodChannel('video360Kaltura_$id');
  }

  Future<bool> loadVideo(String entryId) async {
    assert(entryId != null);
    HashMap<String, String> params = HashMap();
    params["entryId"] = entryId;
    return _channel.invokeMethod('loadVideo', params);
  }

  Future<bool> isPlaying() async {
    return _channel.invokeMethod('isPlaying');
  }

  Future<bool> play() async {
    return _channel.invokeMethod('play');
  }

  Future<bool> pause() async {
    return _channel.invokeMethod('pause');
  }

  Future<void> fullScreen() async {
    return _channel.invokeMethod('fullScreen');
  }

  Future<void> toggleVRMode() async {
    return _channel.invokeMethod('toggleVRMode');
  }

  Future<void> onSizeChanged(double width, double height) {
    HashMap<String, double> newSize = HashMap();
    newSize["width"] = width;
    newSize["height"] = height;
    return _channel.invokeMethod('onSizeChanged', newSize);
  }

  Future<void> seekTo(int position) {
    HashMap<String, int> newPosition = HashMap();
    newPosition["position"] = position;
    return _channel.invokeMethod('seekTo', newPosition);
  }

  Future<void> onPause() {
    return _channel.invokeMethod('onPause');
  }

  Future<void> onResume() {
    return _channel.invokeMethod('onResume');
  }

  Future<void> onOrientationChanged() {
    return _channel.invokeMethod('onOrientationChanged');
  }
}

class Video360PlayerObserver {
  EventChannel _eventChannelState;
  EventChannel _eventChannelDuration;
  EventChannel _eventChannelPosition;
  EventChannel _eventChannelEnded;

  Function _onReceiveState;
  Function _onReceiveDuration;
  Function _onReceivePosition;
  Function _onReceiveEnded;

  Video360PlayerObserver.init(int id) {
    _eventChannelState = EventChannel("video360Kaltura_events_${id}_state");
    _eventChannelState.receiveBroadcastStream().listen((duration) {
      this._onReceiveState(duration);
    });
    _eventChannelDuration = EventChannel("video360Kaltura_events_${id}_duration");
    _eventChannelDuration.receiveBroadcastStream().listen((duration) {
      this._onReceiveDuration(duration);
    });
    _eventChannelPosition = EventChannel("video360Kaltura_events_${id}_position");
    _eventChannelPosition.receiveBroadcastStream().listen((duration) {
      this._onReceivePosition(duration);
    });
    _eventChannelEnded = EventChannel("video360Kaltura_events_${id}_ended");
    _eventChannelEnded.receiveBroadcastStream().listen((duration) {
      this._onReceiveEnded(duration);
    });
  }

  handleStateChange(Function onReceiveDuration) {
    this._onReceiveState = onReceiveDuration;
  }
  handleDurationChange(Function onReceiveDuration) {
    this._onReceiveDuration = onReceiveDuration;
  }
  handlePositionChange(Function onReceiveDuration) {
    this._onReceivePosition = onReceiveDuration;
  }
  handleEndedChange(Function onReceiveDuration) {
    this._onReceiveEnded = onReceiveDuration;
  }
}

typedef void Video360PlayerCreatedCallback(Video360PlayerController controller, Video360PlayerObserver observer);

class Video360Kaltura extends StatefulWidget {

  final Video360PlayerCreatedCallback onCreated;
  final x;
  final y;
  final width;
  final height;
  final partnerId;
  final ovpServerUrl;

  Video360Kaltura({
    Key key,
    @required this.onCreated,
    @required this.x,
    @required this.y,
    @required this.width,
    @required this.height,
    @required this.partnerId,
    @required this.ovpServerUrl,
  });

  @override
  State<StatefulWidget> createState() => _VideoPlayerState();
}

class _VideoPlayerState extends State<Video360Kaltura> with WidgetsBindingObserver {
  Video360PlayerController videoPlayerController;
  bool wasResumed = false;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addObserver(this);
  }

  @override
  void didUpdateWidget(Video360Kaltura oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.width != null && oldWidget.width != widget.width) {
      double width = widget.width;
      double height = widget.height;
      if (Platform.isAndroid) {
        width = width * MediaQuery.of(context).devicePixelRatio;
        height = height * MediaQuery.of(context).devicePixelRatio;
      }
      this.videoPlayerController.onSizeChanged(width, height);
    }
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) async {
    if (state == AppLifecycleState.resumed) {
      this.wasResumed = true;
      await this.videoPlayerController.onResume();
    } else if (state == AppLifecycleState.paused) {
      await this.videoPlayerController.onPause();
    }
    super.didChangeAppLifecycleState(state);
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    super.dispose();
  }

  @override
  void didChangeMetrics() async {
    super.didChangeMetrics();
    if (!this.wasResumed) {
      await this.videoPlayerController.onOrientationChanged();
    }
    this.wasResumed = false;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width,
      height: widget.height,
      color: Colors.red,
      child: nativeView(),
    );
  }

  nativeView() {
    if (Platform.isAndroid) {
      return AndroidView(
        viewType: 'plugins.video_360_kaltura/player_view',
        onPlatformViewCreated: onPlatformViewCreated,
        creationParams: <String,dynamic>{
          "x": widget.x,
          "y": widget.y,
          "width": widget.width * MediaQuery.of(context).devicePixelRatio,
          "height": widget.height * MediaQuery.of(context).devicePixelRatio,
          "partnerId": widget.partnerId,
          "ovpServerUrl": widget.ovpServerUrl
        },
        creationParamsCodec: const StandardMessageCodec(),
      );
    } else {
      return UiKitView(
        viewType: 'plugins.video_360_kaltura/player_view',
        onPlatformViewCreated: onPlatformViewCreated,
        creationParams: <String,dynamic>{
          "x": widget.x,
          "y": widget.y,
          "width": widget.width,
          "height": widget.height,
        },
        creationParamsCodec: const StandardMessageCodec(),
      );
    }
  }

  Future<void> onPlatformViewCreated(id) async {
    if (widget.onCreated == null) {
      return;
    }

    this.videoPlayerController = new Video360PlayerController.init(id);
    widget.onCreated(videoPlayerController, new Video360PlayerObserver.init(id));
  }
}

==> 0.0.5.tar.gz: lib/video360kaltura.dart <==
import 'dart:async';
import 'dart:collection';
import 'dart:io';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class Video360PlayerController {

  MethodChannel _channel;

  Video360PlayerController.init(int id) {
    _channel = new MethodChannel('video360Kaltura_$id');
  }

  Future<bool> loadVideo(String entryId) async {
    assert(entryId != null);
    HashMap<String, String> params = HashMap();
    params["entryId"] = entryId;
    return _channel.invokeMethod('loadVideo', params);
  }

  Future<bool> isPlaying() async {
    return _channel.invokeMethod('isPlaying');
  }

  Future<bool> play() async {
    return _channel.invokeMethod('play');
  }

  Future<bool> pause() async {
    return _channel.invokeMethod('pause');
  }

  Future<void> fullScreen() async {
    return _channel.invokeMethod('fullScreen');
  }

  Future<void> toggleVRMode() async {
    return _channel.invokeMethod('toggleVRMode');
  }

  Future<void> onSizeChanged(double width, double height) {
    HashMap<String, double> newSize = HashMap();
    newSize["width"] = width;
    newSize["height"] = height;
    return _channel.invokeMethod('onSizeChanged', newSize);
  }

  Future<void> seekTo(int position) {
    HashMap<String, int> newPosition = HashMap();
    newPosition["position"] = position;
    return _channel.invokeMethod('seekTo', newPosition);
  }

  Future<void> onPause() {
    return _channel.invokeMethod('onPause');
  }

  Future<void> onResume() {
    return _channel.invokeMethod('onResume');
  }

  Future<void> onOrientationChanged() {
    return _channel.invokeMethod('onOrientationChanged');
  }
}

class Video360PlayerObserver {
  EventChannel _eventChannelState;
  EventChannel _eventChannelDuration;
  EventChannel _eventChannelPosition;
  EventChannel _eventChannelEnded;

  Function _onReceiveState;
  Function _onReceiveDuration;
  Function _onReceivePosition;
  Function _onReceiveEnded;

  Video360PlayerObserver.init(int id) {
    _eventChannelState = EventChannel("video360Kaltura_events_${id}_state");
    _eventChannelState.receiveBroadcastStream().listen((duration) {
      this._onReceiveState(duration);
    });
    _eventChannelDuration = EventChannel("video360Kaltura_events_${id}_duration");
    _eventChannelDuration.receiveBroadcastStream().listen((duration) {
      this._onReceiveDuration(duration);
    });
    _eventChannelPosition = EventChannel("video360Kaltura_events_${id}_position");
    _eventChannelPosition.receiveBroadcastStream().listen((duration) {
      this._onReceivePosition(duration);
    });
    _eventChannelEnded = EventChannel("video360Kaltura_events_${id}_ended");
    _eventChannelEnded.receiveBroadcastStream().listen((duration) {
      this._onReceiveEnded(duration);
    });
  }

  handleStateChange(Function onReceiveDuration) {
    this._onReceiveState = onReceiveDuration;
  }
  handleDurationChange(Function onReceiveDuration) {
    this._onReceiveDuration = onReceiveDuration;
  }
  handlePositionChange(Function onReceiveDuration) {
    this._onReceivePosition = onReceiveDuration;
  }
  handleEndedChange(Function onReceiveDuration) {
    this._onReceiveEnded = onReceiveDuration;
  }
}

typedef void Video360PlayerCreatedCallback(Video360PlayerController controller, Video360PlayerObserver observer);

class Video360Kaltura extends StatefulWidget {

  final Video360PlayerCreatedCallback onCreated;
  final x;
  final y;
  final width;
  final height;
  final String partnerId;
  final String ovpServerUrl;

  Video360Kaltura({
    Key key,
    @required this.onCreated,
    @required this.x,
    @required this.y,
    @required this.width,
    @required this.height,
    @required this.partnerId,
    @required this.ovpServerUrl,
  });

  @override
  State<StatefulWidget> createState() => _VideoPlayerState();
}

class _VideoPlayerState extends State<Video360Kaltura> with WidgetsBindingObserver {
  Video360PlayerController videoPlayerController;
  bool wasResumed = false;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addObserver(this);
  }

  @override
  void didUpdateWidget(Video360Kaltura oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.width != null && oldWidget.width != widget.width) {
      double width = widget.width;
      double height = widget.height;
      if (Platform.isAndroid) {
        width = width * MediaQuery.of(context).devicePixelRatio;
        height = height * MediaQuery.of(context).devicePixelRatio;
      }
      this.videoPlayerController.onSizeChanged(width, height);
    }
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) async {
    if (state == AppLifecycleState.resumed) {
      this.wasResumed = true;
      await this.videoPlayerController?.onResume();
    } else if (state == AppLifecycleState.paused) {
      await this.videoPlayerController.onPause();
    }
    super.didChangeAppLifecycleState(state);
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    super.dispose();
  }

  @override
  void didChangeMetrics() async {
    super.didChangeMetrics();
    if (!this.wasResumed) {
      await this.videoPlayerController.onOrientationChanged();
    }
    this.wasResumed = false;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width,
      height: widget.height,
      color: Colors.black,
      child: nativeView(),
    );
  }

  nativeView() {
    if (Platform.isAndroid) {
      return AndroidView(
        viewType: 'plugins.video_360_kaltura/player_view',
        onPlatformViewCreated: onPlatformViewCreated,
        creationParams: <String,dynamic>{
          "x": widget.x,
          "y": widget.y,
          "width": widget.width * MediaQuery.of(context).devicePixelRatio,
          "height": widget.height * MediaQuery.of(context).devicePixelRatio,
          "partnerId": widget.partnerId,
          "ovpServerUrl": widget.ovpServerUrl
        },
        creationParamsCodec: const StandardMessageCodec(),
      );
    } else {
      return UiKitView(
        viewType: 'plugins.video_360_kaltura/player_view',
        onPlatformViewCreated: onPlatformViewCreated,
        creationParams: <String,dynamic>{
          "x": widget.x,
          "y": widget.y,
          "width": widget.width,
          "height": widget.height,
          "partnerId": widget.partnerId,
          "ovpServerUrl": widget.ovpServerUrl,
        },
        creationParamsCodec: const StandardMessageCodec(),
      );
    }
  }

  Future<void> onPlatformViewCreated(id) async {
    if (widget.onCreated == null) {
      return;
    }

    this.videoPlayerController = new Video360PlayerController.init(id);
    widget.onCreated(videoPlayerController, new Video360PlayerObserver.init(id));
  }
}
